'*Module: Error
'*File: error.bas
'*Purpose: Library of program error handling functions, per BOS standards.

Option Explicit

'Dummy error codes
Global Const EXITERROR = 2     'exit
Global Const CONTERROR = 3      'continue

'Return status from functions
Global Const FAIL = 0
Global Const SUCCEED = 1
Global Const EXIT_STATUS% = 2
Global Const CONTINUE_STATUS% = 3

'Flag for overriding field edit trapping

Global OverRide As Integer

'Flag for field edit errors

Global Edit_Check As Integer

'Flag to move back to field after error

Global Const Reset_Focus% = -1

'Error Groups

Global Const ODBC_GROUP% = 1
Global Const SYBASE_GROUP% = 2
Global Const ALLBASE_GROUP% = 3
Global Const SERVER_OBJECT_GROUP% = 4
Global Const VB_ERROR_GROUP% = 5
Global Const EDIT_GROUP% = 6

'SERVER_OBJECT_GROUP%
Global Const SQL_SYNTAX_ERROR% = 0
Global Const MEMORY_ALLOCATION_ERROR% = 1
Global Const LOGIN_FORM_REQUEST% = 2
Global Const MAX_CONNECTIONS_EXCEEDED% = 3
Global Const NO_DEFAULT_DATABASE% = 4
Global Const MULTI_SERVER_ERROR% = 5
Global Const SERVER_NOT_FOUND% = 6
Global Const SERVER_NOT_IN_ODBC_INI% = 7
Global Const LAST_LOGIN_ODBC_INI_ERROR% = 8

Sub cEditError (ThisControl As Control, Msg As String, Reset_Flag As Integer)

'*Purpose: Error trapping for edits
'*Function: Display error message and reset focus if desired.  Override error if canceling or selecting new transaction for editing.

'OverRide flag if override error, set to true when close form so not catch lostfocus edit checks.
'Reset flag - returns focus to the control

'Declarations

    Dim nStatus As Integer

'End Declarations

    If OverRide% = False Then
        Beep
        MsgBox (Msg$)
        If Reset_Flag% Then
            If ThisControl.Visible Then
                ThisControl.Enabled = True
              ThisControl.SetFocus
            End If
        End If
    End If


End Sub

Sub cMoveTo (ThisControl As Control)
    
'*Purpose: Reposition focus
'*Function: Check if control is visible, then set focus to it.

    On Error GoTo Move_Trap
    
    If ThisControl.Visible Then
        ThisControl.Enabled = True
        ThisControl.SetFocus
    End If

    On Error GoTo 0

Drop_out:

Exit Sub

Move_Trap:
'430 = No current active control, may happen if exit form while on field.
    If Err = 430 Then
    Else
        MsgBox ("Error: " + Str$(Err) + " " + Error$)
    End If

    GoTo Drop_out

End Sub

Function cnErrorHandle (lErrorCode As Long, nGroupCode As Integer, sModule As String, sDetailString As String) As Integer

'*Purpose: Genric error handler
'Long term goal is to have errors stored in a database
' Record consists of a code, how handled etc.
' This is dummied in for the time being

'Declarations

    Dim NL As String

'End Declarations

    NL$ = Chr$(13) + Chr$(10)
    
    Select Case nGroupCode%
    Case SYBASE_GROUP%
'Sybase error code handling
        Select Case lErrorCode&
            Case 5701, 5703                         ' Database Change and US English Errors
            cnErrorHandle% = CONTINUE_STATUS%
            Exit Function
        Case 207, 102                          'SQL syntax errors
            cnErrorHandle% = EXIT_STATUS%
        Case Else
            cnErrorHandle% = EXIT_STATUS%
        End Select
                
    Case Else
'This is extensible for other groups and codes

        Select Case lErrorCode&
        Case CONTERROR
            cnErrorHandle% = CONTINUE_STATUS%
        Case EXITERROR
            cnErrorHandle% = EXIT_STATUS%
        Case Else
            cnErrorHandle% = EXIT_STATUS%
        End Select
    End Select
'***********

    MsgBox ("Error #" + Format$(lErrorCode&, "0") + NL$ + sModule$ + NL$ + sDetailString$)

End Function

